#
# spec file for package fakeroot
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fakeroot
Version:        1.36
Release:        2.2
Summary:        Wrapper that gives a fake root environment
License:        GPL-3.0-or-later
Group:          Development/Tools/Other
URL:            https://tracker.debian.org/pkg/fakeroot
Source0:        http://ftp.debian.org/debian/pool/main/f/fakeroot/%{name}_%{version}.orig.tar.gz#/%{name}_%{version}.orig.tar.gz
Source99:       baselibs.conf
# PATCH-FIX-UPSTREAM fakeroot-1.21-fix-shell-in-fakeroot.patch (deb#828810)
Patch0:         fakeroot-1.21-fix-shell-in-fakeroot
BuildRequires:  autoconf >= 2.71
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  group(sys)
# user(daemon)/group(sys) is required for t.tar testsuite
BuildRequires:  intltool
BuildRequires:  libacl-devel
BuildRequires:  libcap-devel
BuildRequires:  libcap-progs
BuildRequires:  libtool
BuildRequires:  po4a
BuildRequires:  sharutils
BuildRequires:  user(daemon)
Requires(post): update-alternatives
Requires(preun): update-alternatives

%description
fakeroot runs a command in an environment wherein it appears to have
root privileges for file manipulation. fakeroot works by replacing the
file manipulation library functions (chmod(2), stat(2) etc.) by ones
that simulate the effect the real library functions would have had,
had the user really been root.

%prep
%autosetup -p1

%build
./bootstrap
pushd doc
po4a -k 0 --rm-backups --variable "srcdir=../doc/" po4a/po4a.cfg
popd

for type in sysv tcp; do
  mkdir obj-$type
  cd obj-$type
  cat >> configure << 'EOF'
#! /bin/sh
exec ../configure "$@"
EOF
  chmod +x configure
  %configure \
    --libdir=%{_libdir}/libfakeroot \
    --disable-static \
    --with-ipc=$type \
    --program-suffix=-$type
  %make_build
  cd ..
done

%install
for type in sysv tcp; do
  make -C obj-$type install DESTDIR=%{buildroot}
  mv %{buildroot}%{_libdir}/libfakeroot/libfakeroot-0.so \
     %{buildroot}%{_libdir}/libfakeroot/libfakeroot-$type.so
  rm -f %{buildroot}%{_libdir}/libfakeroot/libfakeroot.so
  rm -f %{buildroot}%{_libdir}/libfakeroot/libfakeroot.*a
done

%fdupes -s %{buildroot}

# Create ghost files for "update-alternatives"
ln -sf faked-sysv %{buildroot}%{_bindir}/faked
ln -sf fakeroot-sysv %{buildroot}%{_bindir}/fakeroot
ln -sf faked-sysv.1.gz %{buildroot}%{_mandir}/man1/faked.1.gz
ln -sf fakeroot-sysv.1.gz %{buildroot}%{_mandir}/man1/fakeroot.1.gz
for i in de es fr nl pt ro sv; do
  ln -sf faked-sysv.1.gz %{buildroot}%{_mandir}/$i/man1/faked.1.gz
  ln -sf fakeroot-sysv.1.gz %{buildroot}%{_mandir}/$i/man1/fakeroot.1.gz
done
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/{faked,fakeroot}{,.1%{ext_man}}

%check
for type in sysv tcp; do
  %make_build -C obj-$type check
done

%post
%{_sbindir}/update-alternatives --install %{_bindir}/fakeroot fakeroot %{_bindir}/fakeroot-sysv 20 \
 --slave %{_bindir}/faked faked %{_bindir}/faked-sysv \
 --slave %{_mandir}/man1/fakeroot.1.gz fakeroot.1.gz %{_mandir}/man1/fakeroot-sysv.1.gz \
 --slave %{_mandir}/man1/faked.1.gz faked.1.gz %{_mandir}/man1/faked-sysv.1.gz \
 --slave %{_mandir}/de/man1/fakeroot.1.gz fakeroot.de.1.gz %{_mandir}/de/man1/fakeroot-sysv.1.gz \
 --slave %{_mandir}/de/man1/faked.1.gz faked.de.1.gz %{_mandir}/de/man1/faked-sysv.1.gz \
 --slave %{_mandir}/es/man1/fakeroot.1.gz fakeroot.es.1.gz %{_mandir}/es/man1/fakeroot-sysv.1.gz \
 --slave %{_mandir}/es/man1/faked.1.gz faked.es.1.gz %{_mandir}/es/man1/faked-sysv.1.gz \
 --slave %{_mandir}/fr/man1/fakeroot.1.gz fakeroot.fr.1.gz %{_mandir}/fr/man1/fakeroot-sysv.1.gz \
 --slave %{_mandir}/fr/man1/faked.1.gz faked.fr.1.gz %{_mandir}/fr/man1/faked-sysv.1.gz \
 --slave %{_mandir}/nl/man1/fakeroot.1.gz fakeroot.nl.1.gz %{_mandir}/nl/man1/fakeroot-sysv.1.gz \
 --slave %{_mandir}/nl/man1/faked.1.gz faked.nl.1.gz %{_mandir}/nl/man1/faked-sysv.1.gz \
 --slave %{_mandir}/pt/man1/fakeroot.1.gz fakeroot.pt.1.gz %{_mandir}/pt/man1/fakeroot-sysv.1.gz \
 --slave %{_mandir}/pt/man1/faked.1.gz faked.pt.1.gz %{_mandir}/pt/man1/faked-sysv.1.gz \
 --slave %{_mandir}/ro/man1/fakeroot.1.gz fakeroot.ro.1.gz %{_mandir}/ro/man1/fakeroot-sysv.1.gz \
 --slave %{_mandir}/ro/man1/faked.1.gz faked.ro.1.gz %{_mandir}/ro/man1/faked-sysv.1.gz \
 --slave %{_mandir}/sv/man1/fakeroot.1.gz fakeroot.sv.1.gz %{_mandir}/sv/man1/fakeroot-sysv.1.gz \
 --slave %{_mandir}/sv/man1/faked.1.gz faked.sv.1.gz %{_mandir}/sv/man1/faked-sysv.1.gz

%{_sbindir}/update-alternatives --install %{_bindir}/fakeroot fakeroot %{_bindir}/fakeroot-tcp 10 \
 --slave %{_bindir}/faked faked %{_bindir}/faked-tcp \
 --slave %{_mandir}/man1/fakeroot.1.gz fakeroot.1.gz %{_mandir}/man1/fakeroot-tcp.1.gz \
 --slave %{_mandir}/man1/faked.1.gz faked.1.gz %{_mandir}/man1/faked-tcp.1.gz \
 --slave %{_mandir}/de/man1/fakeroot.1.gz fakeroot.de.1.gz %{_mandir}/de/man1/fakeroot-tcp.1.gz \
 --slave %{_mandir}/de/man1/faked.1.gz faked.de.1.gz %{_mandir}/de/man1/faked-tcp.1.gz \
 --slave %{_mandir}/es/man1/fakeroot.1.gz fakeroot.es.1.gz %{_mandir}/es/man1/fakeroot-tcp.1.gz \
 --slave %{_mandir}/es/man1/faked.1.gz faked.es.1.gz %{_mandir}/es/man1/faked-tcp.1.gz \
 --slave %{_mandir}/fr/man1/fakeroot.1.gz fakeroot.fr.1.gz %{_mandir}/fr/man1/fakeroot-tcp.1.gz \
 --slave %{_mandir}/fr/man1/faked.1.gz faked.fr.1.gz %{_mandir}/fr/man1/faked-tcp.1.gz \
 --slave %{_mandir}/nl/man1/fakeroot.1.gz fakeroot.nl.1.gz %{_mandir}/nl/man1/fakeroot-tcp.1.gz \
 --slave %{_mandir}/nl/man1/faked.1.gz faked.nl.1.gz %{_mandir}/nl/man1/faked-tcp.1.gz \
 --slave %{_mandir}/pt/man1/fakeroot.1.gz fakeroot.pt.1.gz %{_mandir}/pt/man1/fakeroot-tcp.1.gz \
 --slave %{_mandir}/pt/man1/faked.1.gz faked.pt.1.gz %{_mandir}/pt/man1/faked-tcp.1.gz \
 --slave %{_mandir}/ro/man1/fakeroot.1.gz fakeroot.ro.1.gz %{_mandir}/ro/man1/fakeroot-tcp.1.gz \
 --slave %{_mandir}/ro/man1/faked.1.gz faked.ro.1.gz %{_mandir}/ro/man1/faked-tcp.1.gz \
 --slave %{_mandir}/sv/man1/fakeroot.1.gz fakeroot.sv.1.gz %{_mandir}/sv/man1/fakeroot-tcp.1.gz \
 --slave %{_mandir}/sv/man1/faked.1.gz faked.sv.1.gz %{_mandir}/sv/man1/faked-tcp.1.gz

%preun
if [ $1 -eq 0 ]; then
  %{_sbindir}/update-alternatives --remove fakeroot %{_bindir}/fakeroot-sysv
  %{_sbindir}/update-alternatives --remove fakeroot %{_bindir}/fakeroot-tcp
fi

%files
%license COPYING
%doc AUTHORS BUGS DEBUG README doc/README.saving
%ghost %{_bindir}/faked
%ghost %{_sysconfdir}/alternatives/faked
%ghost %{_bindir}/fakeroot
%ghost %{_sysconfdir}/alternatives/fakeroot
%{_bindir}/faked-sysv
%{_bindir}/faked-tcp
%{_bindir}/fakeroot-sysv
%{_bindir}/fakeroot-tcp
%{_libdir}/libfakeroot/
%ghost %{_mandir}/man1/faked.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/faked.1%{ext_man}
%ghost %{_mandir}/man1/fakeroot.1%{ext_man}
%ghost %{_sysconfdir}/alternatives/fakeroot.1%{ext_man}
%{_mandir}/man1/faked-*.1%{?ext_man}
%{_mandir}/man1/fakeroot-*.1%{?ext_man}
%dir %{_mandir}/nl/
%dir %{_mandir}/nl/man1/
%dir %{_mandir}/pt/
%dir %{_mandir}/pt/man1/
%dir %{_mandir}/ro/
%dir %{_mandir}/ro/man1/
%dir %{_mandir}/sv/
%dir %{_mandir}/sv/man1/
%ghost %lang(de) %{_mandir}/de/man1/faked.1%{ext_man}
%ghost %lang(de) %{_mandir}/de/man1/fakeroot.1%{ext_man}
%lang(de) %{_mandir}/de/man1/faked-*.1%{ext_man}
%lang(de) %{_mandir}/de/man1/fakeroot-*.1%{ext_man}
%ghost %lang(es) %{_mandir}/es/man1/faked.1%{ext_man}
%ghost %lang(es) %{_mandir}/es/man1/fakeroot.1%{ext_man}
%lang(es) %{_mandir}/es/man1/faked-*.1%{ext_man}
%lang(es) %{_mandir}/es/man1/fakeroot-*.1%{ext_man}
%ghost %lang(fr) %{_mandir}/fr/man1/faked.1%{ext_man}
%ghost %lang(fr) %{_mandir}/fr/man1/fakeroot.1%{ext_man}
%lang(fr) %{_mandir}/fr/man1/faked-*.1%{ext_man}
%lang(fr) %{_mandir}/fr/man1/fakeroot-*.1%{ext_man}
%ghost %lang(nl) %{_mandir}/nl/man1/faked.1%{ext_man}
%ghost %lang(nl) %{_mandir}/nl/man1/fakeroot.1%{ext_man}
%lang(nl) %{_mandir}/nl/man1/faked-*.1%{ext_man}
%lang(nl) %{_mandir}/nl/man1/fakeroot-*.1%{ext_man}
%ghost %lang(pt) %{_mandir}/pt/man1/faked.1%{ext_man}
%ghost %lang(pt) %{_mandir}/pt/man1/fakeroot.1%{ext_man}
%lang(pt) %{_mandir}/pt/man1/faked-*.1%{ext_man}
%lang(pt) %{_mandir}/pt/man1/fakeroot-*.1%{ext_man}
%ghost %lang(ro) %{_mandir}/ro/man1/faked.1%{ext_man}
%ghost %lang(ro) %{_mandir}/ro/man1/fakeroot.1%{ext_man}
%lang(ro) %{_mandir}/ro/man1/faked-*.1%{ext_man}
%lang(ro) %{_mandir}/ro/man1/fakeroot-*.1%{ext_man}
%ghost %lang(sv) %{_mandir}/sv/man1/faked.1%{ext_man}
%ghost %lang(sv) %{_mandir}/sv/man1/fakeroot.1%{ext_man}
%lang(sv) %{_mandir}/sv/man1/faked-*.1%{ext_man}
%lang(sv) %{_mandir}/sv/man1/fakeroot-*.1%{ext_man}

%changelog
* Wed Aug 28 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.36 (bsc#1229277)
  * Fix build with gcc-14. (Closes: #1074945)
  * Fix FTBFS on armel, armhf, by undefining the t64 flags in communicate.h
    Upload to experimental, for additional testing.
    (Closes: #1065552)
  * New fix for the previous FTBFS on armel, armhf. Work around glibc headers
    aliasing symbols we need to redefine.
    (Closes: #1065552)
  * Fix ABI mismatch on i386, a 32bit arch _without_ the time_t64 ABI
    break.
  * Fix wrappers for fstatat64 et al missing. (Closes: #1078655)
    Add t.perlstat test. Thanks to Johannes Schauer Marin Rodrigues
    and Niels Thykier for help with debugging the problem.
- Drop fakeroot-C99.patch which has been merged upstream
* Fri Jul 26 2024 Martin Jambor <mjambor@suse.com>
- Aded fakeroot-C99.patch to fix C99 violations which prevent building
  with GCC 14.
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 1.35.1
  * big endian fixes
* Fri Jun  7 2024 Dirk Müller <dmueller@suse.com>
- update to 1.35:
  * build fix for platforms that do not have the close_range
  * function
* Wed Jun  5 2024 Ana Guerrero <ana.guerrero@suse.com>
- Update to 1.34
  * faked now ignores SIGWINCH.
- Update to 1.33
  * Patch from Samuel Thibault to add renameat2 support.
- Update to 1.32
  * Updated German translation from Chris Leick.
  * Patch from John Paul Adrian Glaubitz to add build profile to
    allow bootstrapping.
  * Romanian man page translation from Remus-Gabriel Chelu.
  * patch from Rudi Heitbaum to add missing wrapped.h dependency.
- Update to 1.31
  * patch from Johannes Schauer Marin Rodrigues to not use
    temporary file in chown test.
- Update to 1.30
  * tries to cope with time64 on 32-bit architectures.
  * Drop kludge for glibc 2.33.
  * fixes and extends time64 support to fstatat64.
- Remove patch also-wrap-stat-library-call.patch
* Thu Sep  1 2022 Thorsten Kukuk <kukuk@suse.com>
- The manual pages are already in UTF-8 format, so don't convert
  them from latin1 to UTF-8, this will break the encoding
  [bsc#1203020]
* Thu Jul  7 2022 Matthias Eliasson <elimat@opensuse.org>
- Update to 1.29
  * includes patch from Matthias Ellert to handle _STAT_VER on
    ia64.  closes: #1011234.
- Change url to a working one
- Run spec-cleaner
* Wed Apr 27 2022 olaf@aepfle.de
- * autoconf 2.71 required
* Fri Mar 25 2022 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Update to 1.28
  * Revert commit "Use fixed-width members in fake_msg"
  * Annotate sharutils dependency <!nocheck>. (Closes: #982188)
  * Wrap the "stat" library call. Closes: #1001961
  * Work around segfault on ppc64el. Closes: #995393
  * Includes patch from lemonsqueeze to improve fakeroot-tcp
    performance by setting TCP_NODELAY.  closes: #1003596.
  * Includes patch from Samuel Thibault to handle _STAT_VER on
    GNU/Hurd.  closes: #1006151.
  * autoconf 2.71 required
  * Add also-wrap-stat-library-call.patch (deb#1001961)
  * Remove fakeroot-1.20-eglibc-fts-without-LFS.patch
  * Remove fakeroot-drop-tartest.patch
  * Remove 0001-glibc-2.33-compatibility-fixes.patch
  * Remove fakeroot-1.20-lib32.patch
  * Remove stat-ver-riscv.patch
* Sun May 16 2021 Andreas Schwab <schwab@suse.de>
- stat-ver-riscv.patch: fix _STAT_VER on riscv
- reenable testsuite
* Wed Mar 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream changes to fix build with glibc 2.33:
  * 0001-glibc-2.33-compatibility-fixes.patch
* Fri Oct 30 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.25.3 (no changelog)
- Removed fakeroot-1.24-fix-chown.patch
- Removed fakeroot-1.21-hide-dlsym-error.patch
- Rebased fakeroot-1.20-lib32.patch
* Tue Jun  9 2020 Dirk Mueller <dmueller@suse.com>
- add fakeroot-1.24-fix-chown.patch:
  taken from https://salsa.debian.org/clint/fakeroot/-/commit/55e12cb8b02d65b9fc9c3e607794db5e01e2f94f.diff
- skip testsuite on Tumbleweed until underlying issue has been fixed
* Wed Jan 22 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.24:
  + Retry msgsnd() if interrupted by a signal.
  + Detect and handle message queue and semaphore id collision.
- Skip tar test: the test is unstable and keeps on randomly
  failing (add fakeroot-drop-tartest.patch).
* Tue Sep 10 2019 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file
* Tue Sep 10 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Fri Sep  6 2019 Dirk Mueller <dmueller@suse.com>
- update to 1.23;
  * No changelog available, seems just a rebuild with tar.xz
* Wed Nov  8 2017 aavindraa@gmail.com
- Update to version 1.22
  * libfakeroot: Ship the (unused) SONAME link to ensure it gets
    cleaned up automatically.
  * Hide errors from dlsym() unless debugging was enabled. This
    makes builds less noisy and fixes failures in APT test suite
    with glibc 2.24, which started reporting errors for dlsym()
  * On Debian, force the fakeroot shebang to always be /bin/sh
- clean with spec-cleaner
- strip "orig" from tarball file name
* Wed Jun 21 2017 dimstar@opensuse.org
- Add user(daemon) and group(sys) BuildRequires: needed in order to
  pass the test suite.
* Tue Jan 10 2017 aloisio@gmx.com
- Update to version 1.21
  * Portuguese man page translation update from Américo
    Monteiro. Closes (deb#764535).
  * Patch to increase MAX_IPC_BUFFER_SIZE (to cope with evmctl
    sign failure) from Marc Kleine-Budde. Closes (deb#801977).
- Dropped fakeroot-1.20-libcap.patch now handled upstream
- Added fakeroot-1.21-hide-dlsym-error.patch and
  fakeroot-1.21-fix-shell-in-fakeroot.patch
* Tue Jan  3 2017 mpluskal@suse.com
- Small packaging cleanup
* Fri Oct 25 2013 adam@mizerski.pl
- Update to version 1.20:
  See
  http://ftp-master.metadata.debian.org/changelogs/main/f/fakeroot/fakeroot_1.20-1_changelog
  for changes.
- Removed not needed build dependency gcc-c++.
- Added build dependencies: libacl-devel, libcap-devel, libcap-progs.
- Added patches: fakeroot-1.20-lib32.patch, fakeroot-1.20-libcap.patch.
  Also patch fakeroot-1.20-eglibc-fts-without-LFS.patch was copied from debian.
- Added baselibs.conf
- Removed unneded "unset POSIXLY_CORRECT" from build and install sections
- Added /etc/alternatives/* as ghost files
* Sun Apr 29 2012 asterios.dramis@gmail.com
- Update to version 1.18.3:
  See
  http://packages.debian.org/changelogs/pool/main/f/fakeroot/fakeroot_1.18.3-1/changelog#version1.18.3-1
  for changes.
- Changes based on spec-cleaner run.
- Updated License to GPL-3.0+.
- Removed libacl-devel and glibc-devel from build dependencies (not needed).
  Added gcc-c++ as build dependency.
- Install libfakeroot-* libraries in %%{_libdir}/libfakeroot/ instead of
  %%{_libdir}/.
- Use update-alternatives for switching between sysv and tcp ipc.
* Sat Nov 20 2010 jw@novell.com
- description improved.
- it is needed by rpmdevtools.
* Mon Feb 11 2008 jblunck@suse.de
- Initial package build from the Ports:Debian:Auto package
